@@ -1,10 +1,10 @@
 #
-# $Id: Encode.pm,v 2.22 2007/05/29 07:35:27 dankogai Exp dankogai $
+# $Id: Encode.pm,v 2.25 2008/05/07 20:56:05 dankogai Exp dankogai $
 #
 package Encode;
 use strict;
 use warnings;
-our $VERSION = sprintf "%d.%02d", q$Revision: 2.22 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%02d", q$Revision: 2.25 $ =~ /(\d+)/g;
 sub DEBUG () { 0 }
 use XSLoader ();
 XSLoader::load( __PACKAGE__, $VERSION );
@@ -36,7 +36,8 @@ our @EXPORT_OK = (
 
 our %EXPORT_TAGS = (
     all          => [ @EXPORT,    @EXPORT_OK ],
-    fallbacks    => [@FB_CONSTS],
+    default      => [ @EXPORT ],
+    fallbacks    => [ @FB_CONSTS ],
     fallback_all => [ @FB_CONSTS, @FB_FLAGS ],
 );
 
@@ -734,7 +735,7 @@ you're not interested in this, then bitwise-or the bitmask with it.
 
 =back
 
-=Head2 coderef for CHECK
+=head2 coderef for CHECK
 
 As of Encode 2.12 CHECK can also be a code reference which takes the
 ord value of unmapped caharacter as an argument and returns a string
@@ -922,7 +923,7 @@ L<Encode::PerlIO>,
 L<encoding>,
 L<perlebcdic>,
 L<perlfunc/open>,
-L<perlunicode>,
+L<perlunicode>, L<perluniintro>, L<perlunifaq>, L<perlunitut>
 L<utf8>,
 the Perl Unicode Mailing List E<lt>perl-unicode@perl.orgE<gt>
 
